@@ -1,4 +1,6 @@
-## Functions for reading multisite data (both Markus/Rachel's and Jay's)
+## ms_funs.r --- General functions for multisite data (both Markus/Rachel's and Jay's)
+## Author: Stephen J Eglen
+## Copyright: GPL
 ## Mon 10 Sep 2001
 
 ## Functions and variables with "mm" in them are mainly for Markus Meister's
@@ -428,7 +430,7 @@ fourplot <- function(s) {
 
 ######################################################################
 ## Mutual information code.
-## taken from Dan Butt's paper.
+## taken from Dan Butt's 2002 J Neurosci paper.
 prob.r <- function(s)  {
   ## Given the distance bins, return the probability of finding
   ## two neurons a distance r apart.
@@ -1948,24 +1950,6 @@ plot.rate.mslayout.rad <- function(s, frame.num, show.com=FALSE,
   }
 }
 
-plot.rate.mslayout.scale <- function(s) {
-  ## Draw the scale bar for the plots.
-  x <- seq(from=100, to=700, by=100)
-  y <- rep(500, length(x))
-  rates <- seq(from=jay.ms.min.firingrate, to=jay.ms.max.firingrate,
-               length=length(x))
-  radii <-  rates.to.radii(rates)
-
-  symbols( x, y,
-          fg="black", bg="black",
-          circles=radii,
-          xaxt="n", yaxt="n", xlab='', ylab='',
-          inches=FALSE,
-          xlim=s$layout$xlim, ylim=s$layout$ylim,
-          main="legend")
-  text(x, y-200, labels=signif(rates,digits=2))
-}
-
 ## Number of colours to have in the firing rate colourmap
 ## +the colourmap itself.  Reverse the list so that white is low
 ## and black is high.
@@ -2070,7 +2054,7 @@ movie.postage <- function(s, tmin, tmax, file="movies.ps") {
   show.movie(s, seconds=TRUE, delay=0,
              beg=tmin, end=tmax,
              show.com=TRUE, skip.empty=TRUE)
-  plot.rate.mslayout.scale()
+  plot.rate.mslayout.scale(s)
   dev.off()
 }
 
@@ -2381,40 +2365,3 @@ print.mm.s <- function(x) {
   cat(basename(x$file), "\n")
   cat("nchannels ", x$NCells, "\n")
 }
-
-
-
-
-
-######################################################################
-## DELETE these functions soon! Mon 15 Jan 2007
-
-
-old.plot.jay.pos <- function(x, use.rownames=FALSE, ...) {
-  ## Plot the layout of the multisite.  X here should be the pos field
-  ## within the structure. ... allows us to specify other params such as
-  ## "col" for colour of text -- see plot.shifted.jay.pos().
-
-  plot(x[,1], x[,2], asp=1,
-       xlim=jay.ms.lim.x, ylim=jay.ms.lim.y,
-       bty="n",
-       xlab="", ylab="", type="n")
-  if (use.rownames)
-    text(x[,1], x[,2], rownames(x), ...)
-  else
-    text(x[,1], x[,2], ...)
-}
-
-
-old.plot.shifted.jay.pos <- function(s) {
-  ## Add the shifted unit positions, if present, before plotting
-  ## the electrode layout.  Shifted units are coloured red.
-  pos <- s$pos
-  cols <- rep("blue", s$NCells)
-  if (!is.null(s$unit.offsets)) {
-    pos <- pos + s$unit.offsets
-    cols[which(apply(s$unit.offsets^2, 1, sum)>0)] <- "red"
-  }
-  plot.jay.pos(pos, col=cols)
-}
-
